summaryrefslogtreecommitdiffstats
path: root/oti/event-handler/otihandler/cfy_client.py
diff options
context:
space:
mode:
Diffstat (limited to 'oti/event-handler/otihandler/cfy_client.py')
-rw-r--r--oti/event-handler/otihandler/cfy_client.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/oti/event-handler/otihandler/cfy_client.py b/oti/event-handler/otihandler/cfy_client.py
index c823340..4e3de87 100644
--- a/oti/event-handler/otihandler/cfy_client.py
+++ b/oti/event-handler/otihandler/cfy_client.py
@@ -168,7 +168,7 @@ class CfyClient(object):
if not password:
raise CfyClientConsulError("{} value is missing 'cloudify.password'".format(source))
- b64_encoded_str = base64.b64encode(bytes("{}:{}".format(username, password), 'utf-8')).decode("utf-8")
+ b64_encoded_str = base64.b64encode(bytes("{}:{}".format(username, password), "utf-8")).decode("utf-8")
headers = {'Authorization': 'Basic ' + b64_encoded_str.rstrip('\n')}
#headers = {'Authorization': 'Basic ' + '{}:{}'.format(username, password).encode("base64").rstrip('\n')}
@@ -416,8 +416,8 @@ class CfyClient(object):
continue
# Check if the collector supports this VNF Type
- # scn:dti Consul key is authoritative for vnfTypes that a collector supports (not docker_config)
- dti_key = scn + ':dti'
+ # scn:oti Consul key is authoritative for vnfTypes that a collector supports (not docker_config)
+ dti_key = scn + ':oti'
try:
obj = ConsulClient.get_value(dti_key)
except Exception as e:
@@ -531,8 +531,8 @@ class CfyClient(object):
continue
# Check if the collector supports this VNF Type
- # scn:dti Consul key is authoritative for vnfTypes that a collector supports (not docker_config)
- dti_key = scn + ':dti'
+ # scn:oti Consul key is authoritative for vnfTypes that a collector supports (not docker_config)
+ dti_key = scn + ':oti'
try:
obj = ConsulClient.get_value(dti_key)
except Exception as e: